@@ -134,26 +134,33 @@ class SpinQutipInterface(object):
         return qt.tensor(ops)
 
     @staticmethod
-    def qobj(system: spins.SpinHamiltonianSystem, endianess: str = "little") -> qt.Qobj:
-        r"""Returns a QuTiP representation.
+    def qobj(
+        system: Union[spins.SpinHamiltonianSystem, spins.SpinSystem], endianess: str = "little"
+    ) -> qt.Qobj:
+        r"""Returns a QuTiP representation of a spin system or a spin hamiltonian.
 
         Args:
-            system: The spin system
+            system: The spin based system
             endianess: first qubit to the right (little) or left (big)
 
         Returns:
-            qt.Qobj: The QuTiP representation
+            qt.Qobj: The QuTiP representation of spin based system
 
         """
-        number_spins: int
-        number_spins = system.number_spins()
-        spin_operator = 0
-        coeff: complex
+        number_spins: int = system.number_spins()
+        if number_spins != 0:
+            spin_operator: qt.Qobj = qt.Qobj(
+                [[0.0] * 2**number_spins] * 2**number_spins,
+                dims=[[2 for _ in range(number_spins)], [2 for _ in range(number_spins)]],
+            )
+        else:
+            spin_operator = qt.Qobj()
         for key in system.keys():
-            coeff = complex(system.get(key))
+            coeff: complex = complex(system.get(key))
             spin_operator += coeff * SpinQutipInterface.pauli_product_to_qutip(
                 key, number_spins, endianess=endianess
             )
+
         return spin_operator
 
 
